跳到主要内容

TrySendError

搜索

枚举 TrySendError 

源代码
pub enum TrySendError<T> {
    Full(T),
    Closed(T),
}
展开描述

Sender::try_send 返回的错误。

变体



Full(T)

无法在 channel 上发送数据,因为 channel 当前已满,发送需要阻塞。



Closed(T)

通道的接收半部分已被显式关闭或已被 drop。

实现

源代码

impl<T> TrySendError<T>

源代码

pub fn into_inner(self) -> T

消耗 TrySendError,返回未发送的值。

trait 实现

源代码

impl<T: Clone> Clone for TrySendError<T>

源代码

fn clone(&self) -> TrySendError<T>

返回值的副本。 更多信息
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
源代码

impl<T> Debug for TrySendError<T>

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
源代码

impl<T> Display for TrySendError<T>

源代码

fn fmt(&self, fmt: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
源代码

impl<T> Error for TrySendError<T>

1.30.0 · 源代码

fn source(&self) -> Option<&(dyn Error + 'static)>

返回此错误的更底层来源(若有)。 更多信息
1.0.0 · 源代码

fn description(&self) -> &str

👎Deprecated since 1.42.0: use the Display impl or to_string()
1.0.0 · 源代码

fn cause(&self) -> Option<&dyn Error>

👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
源代码

fn provide<'a>(&'a self, request: &mut Request<'a>)

🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type-based access to context intended for error reports. 更多信息
源代码

impl<T> From<SendError<T>> for TrySendError<T>

源代码

fn from(src: SendError<T>) -> TrySendError<T>

从输入类型转换为此类型。
源代码

impl<T: PartialEq> PartialEq for TrySendError<T>

源代码

fn eq(&self, other: &TrySendError<T>) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 != 运算符。默认实现几乎总是够用,除非有非常充分的理由,否则不应被覆盖。
源代码

impl<T: Copy> Copy for TrySendError<T>

源代码

impl<T: Eq> Eq for TrySendError<T>

源代码

impl<T> StructuralPartialEq for TrySendError<T>

自动 trait 实现



impl<T> Freeze for TrySendError<T>
where T: Freeze,



impl<T> RefUnwindSafe for TrySendError<T>
where T: RefUnwindSafe,



impl<T> Send for TrySendError<T>
where T: Send,



impl<T> Sync for TrySendError<T>
where T: Sync,



impl<T> Unpin for TrySendError<T>
where T: Unpin,



impl<T> UnsafeUnpin for TrySendError<T>
where T: UnsafeUnpin,



impl<T> UnwindSafe for TrySendError<T>
where T: UnwindSafe,

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换是 From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获得所有权后的类型。
源代码

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
源代码

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
源代码

impl<T> ToString for T
where T: Display + ?Sized,

源代码

fn to_string(&self) -> String

Converts the given value to a String. 更多信息
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。